# Jackal, Django Rest Framework extension

[![version badge](https://badge.fury.io/py/django-jackal.svg)](https://badge.fury.io/py/django-jackal)

![jackal image](https://imgur.com/XnlU8T9.jpg)

> Warning! This project is for personal use. Therefore, there are no documents, and the code changes are arbitrary.

**Jackal** is extension of Django REST Framework(DRF)
that help you easily implement the necessary features on your web backend server.

## Installation

    pip install django-jackal
